/* BDF - Copyright (c) 2015-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.servlets;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.users.BdfUser;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import javax.servlet.http.HttpSession;
import net.fichotheque.Fichotheque;
import net.fichotheque.sphere.Redacteur;
import net.fichotheque.sphere.Sphere;


/**
 *
 * @author Vincent Calame
 */
public class BDFSession {

    private final Map<String, BdfUser> bdfUserMap = new LinkedHashMap<String, BdfUser>();
    private final Set<String> disabledAuthentificationSharingSet = new LinkedHashSet<String>();
    private final HttpSession session;
    private boolean multiAdmin = false;

    public BDFSession(HttpSession session) {
        this.session = session;
    }

    public HttpSession getHttpSession() {
        return session;
    }

    public boolean isEmpty() {
        return ((!multiAdmin) && (bdfUserMap.isEmpty()));
    }

    public boolean isMultiAdmin() {
        return multiAdmin;
    }

    public void setMultiAdmin(boolean multiAdmin) {
        this.multiAdmin = multiAdmin;
    }

    public BdfUser getBdfUser(String fichothequeName) {
        return bdfUserMap.get(fichothequeName);
    }

    public void addBdfUser(String fichothequeName, BdfUser bdfUser) {
        bdfUserMap.put(fichothequeName, bdfUser);
        disabledAuthentificationSharingSet.remove(fichothequeName);
    }

    public void removeBdfUser(String fichothequeName) {
        bdfUserMap.remove(fichothequeName);
        disabledAuthentificationSharingSet.add(fichothequeName);
    }

    public void removeRedacteur(Redacteur redacteur) {
        String sphereName = redacteur.getSubsetName();
        String login = redacteur.getLogin();
        List<String> removeList = new ArrayList<String>();
        for (Map.Entry<String, BdfUser> entry : bdfUserMap.entrySet()) {
            Redacteur otherRedacteur = entry.getValue().getRedacteur();
            if ((otherRedacteur.getSubsetName().equals(sphereName)) && (otherRedacteur.getLogin().equals(login))) {
                removeList.add(entry.getKey());
            }
        }
        for (String remove : removeList) {
            bdfUserMap.remove(remove);
        }
    }

    public Redacteur checkMatchingBdfUser(BdfServer bdfServer) {
        if (disabledAuthentificationSharingSet.contains(bdfServer.getName())) {
            return null;
        }
        Fichotheque fichotheque = bdfServer.getFichotheque();
        for (BdfUser bdfUser : bdfUserMap.values()) {
            Redacteur redacteur = bdfUser.getRedacteur();
            Sphere sphere = (Sphere) fichotheque.getSubset(redacteur.getSubsetKey());
            if (sphere != null) {
                Redacteur matchingRedacteur = sphere.getRedacteurByLogin(redacteur.getLogin());
                if ((matchingRedacteur != null) && (matchingRedacteur.isActive())) {
                    return matchingRedacteur;
                }
            }
        }
        return null;
    }

    public boolean containsBdfUser(String fichothequeName, BdfUser bdfUser) {
        BdfUser current = bdfUserMap.get(fichothequeName);
        if (current != null) {
            return current.equals(bdfUser);
        } else {
            return false;
        }
    }

}
