/* BdfServer - Copyright (c) 2016-2019 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.storage;

import fr.exemole.bdfserver.api.storage.StorageContent;
import fr.exemole.bdfserver.api.storage.TableExportStorage;
import java.util.List;
import java.util.SortedMap;
import java.util.TreeMap;
import net.fichotheque.exportation.table.TableExportDef;
import net.fichotheque.tools.exportation.table.TableExportDefBuilder;


/**
 *
 * @author Vincent Calame
 */
public class TableExportStorageUnitBuilder {

    private final String name;
    private final TableExportDefBuilder tableExportDefBuilder;
    private final SortedMap<String, StorageContent> map = new TreeMap<String, StorageContent>();

    public TableExportStorageUnitBuilder(String name) {
        this.name = name;
        this.tableExportDefBuilder = new TableExportDefBuilder(name);
    }

    public void addStorageContent(StorageContent storageContent) {
        map.put(storageContent.getPath(), storageContent);
    }

    public TableExportStorage.Unit toTableExportStorageUnit() {
        List<StorageContent> storageContentList = StorageUtils.wrap(map.values().toArray(new StorageContent[map.size()]));
        return new InternalTableExportStorageUnit(name, tableExportDefBuilder.toTableExportDef(), storageContentList);
    }

    public TableExportDefBuilder getTableExportDefBuilder() {
        return tableExportDefBuilder;
    }


    private static class InternalTableExportStorageUnit implements TableExportStorage.Unit {

        private final String name;
        private final TableExportDef tableExportDef;
        private final List<StorageContent> storageContentList;

        public InternalTableExportStorageUnit(String name, TableExportDef tableExportDef, List<StorageContent> storageContentList) {
            this.name = name;
            this.tableExportDef = tableExportDef;
            this.storageContentList = storageContentList;
        }

        @Override
        public String getName() {
            return name;
        }

        @Override
        public TableExportDef getTableExportDef() {
            return tableExportDef;
        }

        @Override
        public List<StorageContent> getStorageContentList() {
            return storageContentList;
        }

    }

}
