/* BdfServer_Commands - Copyright (c) 2015-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.album;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import net.fichotheque.FichothequeEditor;
import net.fichotheque.album.Album;
import net.fichotheque.album.Illustration;
import net.fichotheque.tools.FichothequeTools;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class IllustrationRemoveCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "IllustrationRemove";
    public final static String COMMANDKEY = "_ ALB-11";
    private Illustration illustration;

    public IllustrationRemoveCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.ALBUM + "/" + COMMANDNAME);
        Album album = illustration.getAlbum();
        FichothequeEditor fichothequeEditor = editSession.getFichothequeEditor();
        FichothequeTools.remove(fichothequeEditor, illustration);
        setDone("_ done.album.illustrationremove");
        putResultObject(ALBUM_OBJ, album);
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        illustration = getMandatoryIllustration();
        getPermissionChecker()
                .checkWrite(illustration);
        if (!checkConfirmation()) {
            setError("_ error.empty.confirmationcheck_remove");
            return false;
        }
        return true;
    }

}
