/* BdfServer_Commands - Copyright (c) 2013-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.configuration;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import net.fichotheque.FichothequeEditor;
import net.fichotheque.metadata.FichothequeMetadata;
import net.mapeadores.util.attr.AttributeParser;
import net.fichotheque.utils.FichothequeUtils;
import net.mapeadores.util.attr.AttributeChange;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class FichothequeAttributeChangeCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "FichothequeAttributeChange";
    public final static String COMMANDKEY = "_ CNF-02";
    public final static String ATTRIBUTES_PARAMNAME = "attributes";
    private AttributeChange attributeChange;

    public FichothequeAttributeChangeCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.CONFIGURATION + "/" + COMMANDNAME);
        FichothequeEditor fichothequeEditor = editSession.getFichothequeEditor();
        FichothequeMetadata metadata = fichotheque.getFichothequeMetadata();
        FichothequeUtils.changeAttributes(fichothequeEditor, metadata, attributeChange);
        setDone("_ done.global.attributechange");
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        checkFichothequeAdmin();
        String attributes = getMandatory(ATTRIBUTES_PARAMNAME);
        this.attributeChange = AttributeParser.parse(attributes);
        return true;
    }

}
