/* BdfServer_Commands - Copyright (c) 2020-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.edition;

import fr.exemole.bdfserver.api.BdfServer;
import static fr.exemole.bdfserver.api.instruction.BdfInstructionConstants.CORPUS_OBJ;
import static fr.exemole.bdfserver.api.instruction.BdfInstructionConstants.FICHEMETA_OBJ;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.EditionEngine;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import net.fichotheque.corpus.FicheMeta;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class FicheAlbumChangeCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "FicheAlbumChange";
    private FicheMeta ficheMeta;

    public FicheAlbumChangeCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.EDITION + "/" + COMMANDNAME);
        EditionEngine.croisementOnly(editSession, this, requestMap, ficheMeta);
        setDone("_ done.edition.fichealbumupdate");
        putResultObject(CORPUS_OBJ, ficheMeta.getCorpus());
        putResultObject(FICHEMETA_OBJ, ficheMeta);
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        ficheMeta = getMandatoryFicheMeta();
        getPermissionChecker()
                .checkWrite(ficheMeta);
        return true;
    }

}
