/* BdfServer_Commands - Copyright (c) 2012-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.exportation;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.balayage.Balayage;
import fr.exemole.bdfserver.api.configuration.PathConfiguration;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.managers.BalayageManager;
import fr.exemole.bdfserver.tools.balayage.BalayageUtils;
import fr.exemole.bdfserver.tools.configuration.PathConfigurationBuilder;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import fr.exemole.bdfserver.tools.runners.BalayageRunner;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class BalayageRunCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "BalayageRun";
    public final static String MODE_PARAMNAME = "mode";
    private Balayage balayage;
    private String mode;

    public BalayageRunCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return false;
    }

    @Override
    protected void doCommand() {
        PathConfiguration pathConfiguration = PathConfigurationBuilder.build(bdfServer);
        BalayageRunner.Result result = BalayageRunner.run(balayage, mode, bdfServer, pathConfiguration);
        putResultObject(BALAYAGE_OBJ, balayage);
        if (result.hasError()) {
            setCommandMessage(result.getError());
        } else {
            putResultObject(BALAYAGELOG_OBJ, result.getBalayageLog());
        }
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        getPermissionChecker()
                .checkAdmin("balayagerun");
        BalayageManager balayageManager = bdfServer.getBalayageManager();
        balayage = BdfInstructionUtils.getMandatoryBalayage(balayageManager, requestMap);
        mode = requestMap.getParameter(MODE_PARAMNAME);
        if (mode != null) {
            if (mode.length() == 0) {
                mode = null;
            } else if (!BalayageUtils.containsMode(balayage, mode)) {
                throw new BdfInstructionException(BdfInstructionUtils.unknownParameterValue(MODE_PARAMNAME, mode));
            }
        }
        return true;
    }

}
