/* BdfServer_Commands - Copyright (c) 2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.exportation;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionConstants;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import java.io.IOException;
import java.io.InputStream;
import net.fichotheque.EditOrigin;
import net.fichotheque.exportation.transformation.TemplateContentDescription;
import net.fichotheque.exportation.transformation.TemplateDescription;
import net.fichotheque.exportation.transformation.TemplateKey;
import net.mapeadores.util.request.FileValue;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class TemplateBinaryUpdateCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "TemplateBinaryUpdateCommand";
    public final static String COMMANDKEY = "_ EXP-36";
    public final static String FILE_PARAMNAME = "file";
    private TemplateKey templateKey;
    private String path;

    public TemplateBinaryUpdateCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        FileValue fileValue = requestMap.getFileValue(FILE_PARAMNAME);
        if (fileValue == null) {
            throw new BdfInstructionException(BdfInstructionUtils.emptyMandatoryParameter(FILE_PARAMNAME));
        }
        if (fileValue.length() > 0) {
            EditOrigin editOrigin = bdfUser.newEditOrigin(Domains.EXPORTATION + "/" + COMMANDNAME);
            try (InputStream is = fileValue.getInputStream()) {
                TemplateDescription templateDescription = bdfServer.getTransformationManager().putTemplateContent(templateKey, path, is, editOrigin);
                if (templateDescription != null) {
                    putResultObject(BdfInstructionConstants.TEMPLATEDESCRIPTION_OBJ, templateDescription);
                    putResultObject(BdfInstructionConstants.TEMPLATECONTENTDESCRIPTION_OBJ, templateDescription.getTemplateContentDescription(path));
                    setDone("_ done.exportation.templatebinaryupdate");
                }
            } catch (IOException ioe) {
                setError("_ error.exception.templatecontent_io", ioe.getMessage());
            }
        }
        fileValue.free();
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        checkFichothequeAdmin();
        TemplateDescription templateDescription = BdfInstructionUtils.getMandatoryTemplateDescription(bdfServer, requestMap);
        TemplateContentDescription templateContentDescription = BdfInstructionUtils.getMandatoryTemplateContentDescription(templateDescription, requestMap);
        this.templateKey = templateContentDescription.getTemplateKey();
        this.path = templateContentDescription.getPath();
        return true;
    }

}
