/* BdfServer_Commands - Copyright (c) 2012-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.thesaurus;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import net.fichotheque.NoRemoveableSubsetException;
import net.fichotheque.SubsetKey;
import net.fichotheque.thesaurus.Thesaurus;
import net.mapeadores.util.exceptions.ShouldNotOccurException;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class ThesaurusRemoveCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "ThesaurusRemove";
    public final static String COMMANDKEY = "_ THS-04";
    private Thesaurus thesaurus;

    public ThesaurusRemoveCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.THESAURUS + "/" + COMMANDNAME);
        SubsetKey thesaurusKey = thesaurus.getSubsetKey();
        try {
            editSession.getFichothequeEditor().removeThesaurus(thesaurus);
            setDone("_ done.thesaurus.thesaurusremove", thesaurusKey.getSubsetName());
            putResultObject(SUBSETKEY_OBJ, thesaurusKey);
        } catch (NoRemoveableSubsetException nrse) {
            throw new ShouldNotOccurException("test done before");
        }
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        checkFichothequeAdmin();
        thesaurus = getMandatoryThesaurus();
        if (!checkConfirmation()) {
            setError("_ error.empty.confirmationcheck_remove");
            return false;
        }
        if (!thesaurus.isRemoveable()) {
            setError("_ error.notremoveable.thesaurus");
            return false;
        }
        return true;
    }

}
