/* BdfServer_Html - Copyright (c) 2021-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.html.jslib;

import fr.exemole.bdfserver.api.storage.ResourceFolder;
import fr.exemole.bdfserver.api.storage.ResourceStorage;
import fr.exemole.bdfserver.api.storage.ResourceStorages;
import fr.exemole.bdfserver.tools.apps.AppConf;
import fr.exemole.bdfserver.tools.storage.StorageUtils;
import java.util.HashSet;
import java.util.Set;
import net.mapeadores.util.text.RelativePath;


/**
 *
 * @author Vincent Calame
 */
public final class JsLibUtils {

    private JsLibUtils() {

    }

    public static JsLib getAppJsLib(ResourceStorages resourceStorages, AppConf appConf) {
        Set<String> pathSet = new HashSet<String>();
        Set<String> familySet = new HashSet<String>();
        JsLibBuilder jsLibBuilder = JsLibBuilder.init()
                .setCurrentAppName(appConf.getAppName());
        for (String jsPath : appConf.getArray(AppConf.CORE_JSORDER)) {
            if (!pathSet.contains(jsPath)) {
                jsLibBuilder.addAppJs(jsPath);
                pathSet.add(jsPath);
            }
        }
        RelativePath jsFolderPath = StorageUtils.buildAppResourcePath(appConf.getAppName(), "js");
        RelativePath templatesFolderPath = StorageUtils.buildAppResourcePath(appConf.getAppName(), "templates");
        RelativePath libTemplatesFolderPath = StorageUtils.buildAppResourcePath(appConf.getAppName(), "lib/templates");
        for (ResourceStorage resourceStorage : resourceStorages) {
            ResourceFolder jsFolder = resourceStorage.getResourceFolder(jsFolderPath);
            if (jsFolder != null) {
                addJsPath(jsLibBuilder, pathSet, jsFolder, "");
            }
            ResourceFolder templatesFolder = resourceStorage.getResourceFolder(templatesFolderPath);
            if (templatesFolder != null) {
                if (!familySet.contains("")) {
                    jsLibBuilder.addAppTemplateFamily("");
                    familySet.add("");
                }
            }
            ResourceFolder libTemplatesFolder = resourceStorage.getResourceFolder(libTemplatesFolderPath);
            if (libTemplatesFolder != null) {
                for (ResourceFolder subFolder : libTemplatesFolder.getSubfolderList()) {
                    String familyName = subFolder.getName();
                    if (!familySet.contains(familyName)) {
                        jsLibBuilder.addAppTemplateFamily(familyName);
                        familySet.add(familyName);
                    }
                }
            }
        }
        return jsLibBuilder.toJsLib();
    }

    private static void addJsPath(JsLibBuilder jsLibBuilder, Set<String> pathSet, ResourceFolder folder, String folderPath) {
        for (ResourceFolder subfolder : folder.getSubfolderList()) {
            addJsPath(jsLibBuilder, pathSet, subfolder, folderPath + subfolder.getName() + "/");
        }
        for (String resourceName : folder.getResourceNameList()) {
            if (resourceName.endsWith(".js")) {
                String jsPath = folderPath + resourceName;
                if (!pathSet.contains(jsPath)) {
                    jsLibBuilder.addAppJs(folderPath + resourceName);
                }
            }
        }
    }

}
