/* BdfServer_Multi - Copyright (c) 2018-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.multi.api;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.storage.JsAnalyser;
import fr.exemole.bdfserver.api.storage.ResourceStorages;
import fr.exemole.bdfserver.conf.BdfServerDirs;
import fr.exemole.bdfserver.multi.MultiConf;
import fr.exemole.bdfserver.multi.commands.CreationParameters;
import fr.exemole.bdfserver.tools.docstream.DocStreamFactory;
import java.util.SortedSet;
import net.fichotheque.EditOrigin;
import net.mapeadores.util.buildinfo.BuildInfo;
import net.mapeadores.util.io.DocStream;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.localisation.MessageLocalisation;
import net.mapeadores.util.localisation.MessageLocalisationProvider;
import net.mapeadores.util.mimetype.MimeTypeResolver;
import net.mapeadores.util.text.RelativePath;


/**
 *
 * @author Vincent Calame
 */
public interface Multi {

    public MultiConf getMultiConf();

    public String getServletContextName();

    public boolean isAuthentificationSharingAllowed();

    public ResourceStorages getWebappsResourceStorages();

    public MimeTypeResolver getMimeTypeResolver();

    public JsAnalyser getWebappsJsAnalyser();

    public SortedSet<String> getExistingNameSet();

    public boolean isInit(String fichothequeName);

    public BdfServer getBdfServer(String fichothequeName);

    public BdfServerDirs getBdfServerDirs(String fichothequeName);

    public void createFichotheque(CreationParameters creationParameters);

    public BuildInfo getBuildInfo();

    public MultiMetadata getMultiMetadata();

    public MultiEditor getMultiEditor(EditOrigin editOrigin);

    public MessageLocalisationProvider getMessageLocalisationProvider();

    public default Lang getAdminLang() {
        return getMultiMetadata().getWorkingLangs().get(0);
    }

    public default MessageLocalisation getAdminMessageLocalisation() {
        return getMessageLocalisationProvider().getMessageLocalisation(getAdminLang());
    }

    public default DocStream getResourceDocStream(RelativePath relativePath) {
        return DocStreamFactory.getResourceDocStream(getWebappsResourceStorages(), relativePath, getMimeTypeResolver());
    }

    public default boolean isEmpty() {
        return getExistingNameSet().isEmpty();
    }

    public default boolean containsFichotheque(String fichothequeName) {
        return getExistingNameSet().contains(fichothequeName);
    }

}
