/* BdfServer_Multi - Copyright (c) 2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.multi.jsonproducers.user;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.conf.BdfServerDirs;
import fr.exemole.bdfserver.multi.api.Multi;
import fr.exemole.bdfserver.multi.api.MultiConstants;
import fr.exemole.bdfserver.multi.jsonproducers.MultiJsonProducer;
import fr.exemole.bdfserver.multi.tools.FichothequeInfo;
import fr.exemole.bdfserver.storage.directory.tools.RedacteurChecker;
import java.util.ArrayList;
import java.util.List;
import net.fichotheque.SubsetKey;
import net.fichotheque.sphere.Redacteur;
import net.fichotheque.sphere.Sphere;
import net.mapeadores.util.json.JsonProducer;
import net.mapeadores.util.logging.LogUtils;


/**
 *
 * @author Vincent Calame
 */
public final class UserJsonProducerFactory {

    private UserJsonProducerFactory() {

    }

    public static JsonProducer getJsonProducer(Multi multi, BdfUser bdfUser, String json) {
        MultiJsonProducer jsonProducer = new MultiJsonProducer(true, multi.getMessageLocalisationProvider().getMessageLocalisation(bdfUser.getLangPreference()));
        switch (json) {
            case MultiConstants.PRESENCE_JSON: {
                List<FichothequeInfo> list = scan(multi, bdfUser);
                jsonProducer.add(new PresenceJsonProperty(list, bdfUser.getWorkingLang()));
                break;
            }
            default: {
                jsonProducer.setCommandMessage(LogUtils.error("_ error.unknown.json", json));
            }

        }
        return jsonProducer;
    }

    private static List<FichothequeInfo> scan(Multi multi, BdfUser bdfUser) {
        List<FichothequeInfo> list = new ArrayList<FichothequeInfo>();
        Redacteur redacteur = bdfUser.getRedacteur();
        SubsetKey sphereKey = redacteur.getSubsetKey();
        String login = redacteur.getLogin();
        for (String name : multi.getExistingNameSet()) {
            if (multi.isInit(name)) {
                BdfServer bdfServer = multi.getBdfServer(name);
                Sphere sphere = (Sphere) bdfServer.getFichotheque().getSubset(sphereKey);
                if (sphere != null) {
                    Redacteur otherRedacteur = sphere.getRedacteurByLogin(login);
                    if ((otherRedacteur != null) && (otherRedacteur.isActive())) {
                        list.add(new FichothequeInfo(name, bdfServer));
                    }
                }
            } else {
                BdfServerDirs bdfServerDirs = multi.getBdfServerDirs(name);
                boolean here = RedacteurChecker.containsRedacteur(redacteur, bdfServerDirs);
                if (here) {
                    list.add(new FichothequeInfo(name, bdfServerDirs));
                }
            }
        }
        return list;
    }

}
