/* global BDF,ID,Transformation,CodeMirror,Overlay,$$ */

Transformation.Overlay = {};

/******************************************************************************
* Appel des différents formulaires
******************************************************************************/
Transformation.Overlay.showTemplateCreationForm = function (transformationKey) {
    if (!BDF.confirmUnload()) {
        return;
    }
    var $transformation = BDF.$({role: "transformation", transformationKey: transformationKey});
    var formId = BDF.generateId();
    var withPropertiesOdt, tableExportArray;
    _initPropertiesInfo();
    Overlay.start({
        header: BDF.Loc.escape("_ EXP-31"),
        content: BDF.render("transformation:overlay-templatecreationform", {
            transformationKey: transformationKey,
            formId: formId,
            title: BDF.$($transformation, {role: "transformation-title"}).html(),
            withOdt: Transformation.hasOdtTemplate(transformationKey),
            withPropertiesOdt: withPropertiesOdt,
            withExtraction: Transformation.hasExportationDef(transformationKey),
            tableExportArray: tableExportArray,
            commandKey: "EXP-31",
            commandUrl: BDF.getCommandUrl("EXP-31")
        }),
        footer: BDF.render("bdf:overlay-footer", {
            submit: {
                locKey: "_ submit.transformation.templatecreation"
            }}),
        afterStart: function ($overlayDialog) {
            $$(formId, "typeselect").change(function () {
                _typeChange(this);
            });
        },
        formAttrs: {
            action: BDF.URL + "exportation",
            method: "POST"
        },
        ajaxForm: {
            dataType: "json",
            success: function (data, textStatus, jqXHR, $form) {
                var done = BDF.checkError(data);
                if (done) {
                    BDF.Pane.clearMain();
                    Overlay.end($form, function () {
                        BDF.showCommandMessage(data.commandMessage);
                        Transformation.insertTemplateDescription(data.templateDescription);
                    });
                 }
            }
        }
    });
    
    function _initPropertiesInfo() {
        let contentPath = transformationKey + ".txt";
        withPropertiesOdt = Transformation.hasPropertiesOdtTemplate(transformationKey);
        tableExportArray = [];
        if (withPropertiesOdt) {
            for(let tableExport of Transformation.tableExportArray) {
                if (__isHere(tableExport)) {
                    tableExportArray.push(tableExport);
                }
            }
        }
        
        function __isHere(tableExport) {
            for(let content of tableExport.contentArray) {
                if (content.path === contentPath) {
                    return true;
                }
            }
            return false;
        }
    }
    
    
    function _typeChange(typeSelect) {
        let option = typeSelect.options[typeSelect.selectedIndex].value;
        if (option === "odt_properties") {
            $$(formId, "options", "properties").removeClass("hidden");
            $$(formId, "options", "xslt").addClass("hidden");
        } else {
            $$(formId, "options", "properties").addClass("hidden");
            $$(formId, "options", "xslt").removeClass("hidden");
        }
    }
};

Transformation.Overlay.showTemplateRemoveConfirm = function (templateKey) {
    var templateDescription = Transformation.getTemplateDescription(templateKey);
    if (!templateDescription) {
        return;
    }
    Overlay.start({
        header: BDF.Loc.escape("_ EXP-32"),
        content: BDF.render("transformation:overlay-templateremoveconfirm", {
            templateKey: templateKey,
            title: templateDescription.title,
            commandKey: "EXP-32",
            commandUrl: BDF.getCommandUrl("EXP-32")
        }),
        footer: BDF.render("bdf:overlay-footer", {
            submit: {
                locKey: '_ submit.transformation.templateremove'
            }}),
        formAttrs: {
            action: BDF.URL + "exportation",
            method: "POST"
        },
        ajaxForm: {
            dataType: "json",
            success: function (data, textStatus, jqXHR, $form) {
                var done = BDF.checkError(data);
                var commandMessage = data.commandMessage;
                if (done) {
                    Overlay.end($form, function () {
                        BDF.showCommandMessage(commandMessage);
                        Transformation.removeTemplate(templateKey);
                    });
                }
            }
        }
    });
};

Transformation.Overlay.showTemplateContentRemoveConfirm = function (templateKey, path) {
    var templateDescription = Transformation.getTemplateDescription(templateKey);
    if (!templateDescription) {
        return;
    }
    Overlay.start({
        header: BDF.Loc.escape("_ EXP-34"),
        content: BDF.render("transformation:overlay-templatecontentremoveconfirm", {
            templateKey: templateKey,
            title: templateDescription.title,
            completeName: Transformation.split(templateKey).templateName,
            path: path,
            commandKey: "EXP-34",
            commandUrl: BDF.getCommandUrl("EXP-34")
        }),
        footer: BDF.render("bdf:overlay-footer", {
            submit: {
                locKey: '_ submit.transformation.templatecontentremove'
            }}),
        formAttrs: {
            action: BDF.URL + "exportation",
            method: "POST"
        },
        ajaxForm: {
            dataType: "json",
            success: function (data, textStatus, jqXHR, $form) {
                var done = BDF.checkError(data);
                if (done) {
                    BDF.Pane.clearMain();
                    Overlay.end($form, function() {
                        BDF.showCommandMessage(data.commandMessage);
                        Transformation.updateTemplateDescription(data.templateDescription);
                    });
                }
            }
        }
    });
};

Transformation.Overlay.showExtractionTest = function (templateKey) {
    var extractionTestPath = Transformation.getTestPath(templateKey) + ".xml";
    if (Transformation.isCompilation(templateKey)) {
        extractionTestPath += "?limit=1";
    }
    var testAreaId = BDF.generateId();
    Overlay.start({
        header: BDF.Loc.escape("_ title.transformation.extractiontest"),
        content: BDF.render("transformation:overlay-extractiontest", {
            templateKey: templateKey,
            testAreaId: testAreaId
        }),
        footer: "",
        afterStart: function ($overlayDialog) {
            var options = {
                theme: 'bdf',
                lineWrapping: false,
                lineNumbers: true,
                editable: false,
                indentUnit: 4,
                mode: "xml"
            };
            var codeMirror = BDF.toCodeMirror(ID(testAreaId), options);
            $.ajax({
                url: extractionTestPath,
                dataType: "text",
                success: function (data) {
                    codeMirror.setValue(data);
                },
                error: function (jqXHR, textStatus, errorThrown) {
                    codeMirror.setValue(BDF.Loc.get("_ error.unsupported.extractiontest"));
                }
            });
        }
    });
};

Transformation.Overlay.showSimpleTemplateTest = function (templateKey) {
    var htmlTestPath = Transformation.getTestPath(templateKey) + ".html";
    if (Transformation.isCompilation(templateKey)) {
        htmlTestPath += "?limit=1";
    }
    Overlay.start({
        header: BDF.Loc.escape("_ title.transformation.simpletemplatetest"),
        content: BDF.render("transformation:overlay-simpletemplatetest", {
            url: htmlTestPath
        }),
        footer: ""
    });
};

Transformation.Overlay.showBinaryUpdate = function (templateKey, path) {
    Overlay.start({
        header: BDF.Loc.escape("_ EXP-36"),
        content: BDF.render("transformation:overlay-binaryupdate", {
            templateKey: templateKey,
            path: path,
            commandKey: "EXP-36",
            commandUrl: BDF.getCommandUrl("EXP-36")
        }),
        footer: ""
    });
};
