/* FichothequeLib_Tools - Copyright (c) 2011-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.extraction;

import java.util.Locale;
import net.fichotheque.extraction.LinkAnalyser;
import net.fichotheque.extraction.ModeResolver;
import net.fichotheque.extraction.def.ExtraitAddendaDef;
import net.fichotheque.extraction.def.ExtraitAlbumDef;
import net.fichotheque.extraction.def.ExtraitCorpusDef;
import net.fichotheque.extraction.def.ExtraitThesaurusDef;
import net.fichotheque.extraction.run.AddendaExtractor;
import net.fichotheque.extraction.run.AlbumExtractor;
import net.fichotheque.extraction.run.CorpusExtractor;
import net.fichotheque.extraction.run.ExtractorProvider;
import net.fichotheque.extraction.run.ThesaurusExtractor;
import net.mapeadores.util.text.TypoOptions;


/**
 *
 * @author Vincent Calame
 */
public final class ExtractionContextUtils {

    public final static ExtractorProvider DEFAULT_EXTRACTORPROVIDER = new DefaultExtractorProvider();
    public final static LinkAnalyser DEFAULT_LINKANALYSER = new DefaultLinkAnalyser();
    public final static ModeResolver DEFAULT_MODERESOLVER = new DefaultModeResolver();


    private ExtractionContextUtils() {
    }


    private static class DefaultLinkAnalyser implements LinkAnalyser {

        private DefaultLinkAnalyser() {
        }

        @Override
        public boolean isExternalLink(String href) {
            if (href == null) {
                return false;
            }
            return (href.indexOf("://") > 0);
        }

    }


    private static class DefaultExtractorProvider implements ExtractorProvider {

        private DefaultExtractorProvider() {
        }

        @Override
        public AddendaExtractor getAddendaExtractor(ExtraitAddendaDef extraitAddendaDef) {
            return new AddendaExtractorImpl(extraitAddendaDef);
        }

        @Override
        public AlbumExtractor getAlbumExtractor(ExtraitAlbumDef extraitAlbumDef) {
            return new AlbumExtractorImpl(extraitAlbumDef);
        }

        @Override
        public CorpusExtractor getCorpusExtractor(ExtraitCorpusDef extraitCorpusDef) {
            return new CorpusExtractorImpl(extraitCorpusDef);
        }

        @Override
        public ThesaurusExtractor getThesaurusExtractor(ExtraitThesaurusDef extraitThesaurusDef) {
            return new ThesaurusExtractorImpl(extraitThesaurusDef);
        }

    }


    private static class DefaultModeResolver implements ModeResolver {

        private final TypoOptions typoOptions = TypoOptions.getTypoOptions(Locale.ENGLISH);


        private DefaultModeResolver() {

        }

        @Override
        public String toCData(String mode, String sValue) {
            switch (mode) {
                case "ficheblock":
                    return FicheblockMode.resolve(sValue);
                default:
                    return "";
            }
        }

    }


}
