/* UtilLib - Copyright (c) 2011-2018 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.mapeadores.util.attr;

import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;


/**
 *
 * @author Vincent Calame
 */
public class AttributeChangeBuilder extends AttributesBuilder {

    private final Set<AttributeKey> removedKeySet = new LinkedHashSet<AttributeKey>();

    public AttributeChangeBuilder() {
    }

    public AttributeChangeBuilder(Attributes initAttributes) {
        super(initAttributes);
    }

    public void putRemovedAttributeKey(AttributeKey attributeKey) {
        removedKeySet.add(attributeKey);
    }

    public void merge(AttributeChangeBuilder otherAttributeChangeBuilder) {
        for (AttributeKey otherAttributeKey : otherAttributeChangeBuilder.removedKeySet) {
            removedKeySet.add(otherAttributeKey);
        }
        super.merge((AttributesBuilder) otherAttributeChangeBuilder);
    }

    public AttributeChange toAttributeChange() {
        Attributes changedAttributes = toAttributes();
        for (Attribute attribute : changedAttributes) {
            removedKeySet.remove(attribute.getAttributeKey());
        }
        List<AttributeKey> removedAttributeKeyList;
        if (removedKeySet.isEmpty()) {
            removedAttributeKeyList = AttributeUtils.EMPTY_ATTRIBUTEKEYLIST;
        } else {
            removedAttributeKeyList = AttributeUtils.wrap(removedKeySet.toArray(new AttributeKey[removedKeySet.size()]));
        }
        return new InternalChangeAttributeHolder(changedAttributes, removedAttributeKeyList);
    }


    private static class InternalChangeAttributeHolder implements AttributeChange {

        private final Attributes changedAttributes;
        private final List<AttributeKey> removedAttributeKeyList;

        private InternalChangeAttributeHolder(Attributes changedAttributes, List<AttributeKey> removedAttributeKeyList) {
            this.changedAttributes = changedAttributes;
            this.removedAttributeKeyList = removedAttributeKeyList;
        }

        @Override
        public Attributes getChangedAttributes() {
            return changedAttributes;
        }

        @Override
        public List<AttributeKey> getRemovedAttributeKeyList() {
            return removedAttributeKeyList;
        }

    }


}
